@@ -1,9 +1,9 @@
 from __future__ import annotations
 
 import json
+import typing as t
 from decimal import Decimal
 from pathlib import Path
-from typing import List, Optional
 
 import shopify
 
@@ -13,6 +13,7 @@ from .schema import (
     CreateMetafieldDefinitionInput,
     MetafieldDefinition,
     MetafieldType,
+    Publication,
     ShopifyBook,
 )
 from .utils import concunrrently_handle_tasks
@@ -63,7 +64,7 @@ class ShopifyBookService:
         shop = to_shopify_shop(data["data"]["shop"])
         return shop
 
-    def get_book_by_id(self, product_id: int) -> Optional[ShopifyBook]:
+    def get_book_by_id(self, product_id: int) -> t.Optional[ShopifyBook]:
         """
         Gets a book by its product ID.
 
@@ -98,6 +99,8 @@ class ShopifyBookService:
             operation_name="productVariantByISBN",
         )
         data = json.loads(result)
+        edges = data["data"]["productVariants"]["edges"]
+        print(edges)
         has_book = len(data["data"]["productVariants"]["edges"]) > 0
         return has_book
 
@@ -122,7 +125,7 @@ class ShopifyBookService:
         except KeyError:
             raise ValueError(data["errors"])
 
-    def create_books(self, book_inputs: List[CreateBookInput]) -> List[ShopifyBook]:
+    def create_books(self, book_inputs: t.List[CreateBookInput]) -> t.List[ShopifyBook]:
         """
         Creates multiple books concurrently in the Shopify store.
 
@@ -174,6 +177,53 @@ class ShopifyBookService:
             operation_name="productDelete",
         )
 
+    def get_publications(self) -> list[Publication]:
+        """
+        Gets a list of publications in the Shopify store.
+
+        Returns:
+            list[any]: A list of publication objects.
+        """
+        result = shopify.GraphQL().execute(
+            query=document, operation_name="publications"
+        )
+        data = json.loads(result)
+        publications: t.List[Publication] = []
+        for edge in data["data"]["publications"]["edges"]:
+            pub_data = edge["node"]
+            publications.append(Publication(gid=pub_data["id"], name=pub_data["name"]))
+        return publications
+
+    def publish_product(self, product_id: int, publication_ids: list[int]) -> dict:
+        """
+        Publishes a product to one or more publications.
+
+        Args:
+            product_id (int): The ID of the product to be published.
+            publication_ids (list[int]): A list of publication IDs to which the product will be published.
+
+        Returns:
+            dict: A dictionary containing the result of the GraphQL query executed to publish the product.
+
+        Raises:
+            Any exceptions that may be raised by the Shopify GraphQL API.
+
+        Example usage:
+            publish_product(12345, [67890, 12345])
+        """
+        result = shopify.GraphQL().execute(
+            query=document,
+            variables=dict(
+                id=f"gid://shopify/Product/{product_id}",
+                input=[
+                    {"publicationId": f"gid://shopify/Publication/{publication_id}"}
+                    for publication_id in publication_ids
+                ],
+            ),
+            operation_name="publishablePublish",
+        )
+        return result
+
     def setup_default_metafield_definitions(self):
         """
         Sets up default metafield definitions for books in the Shopify store.
@@ -192,11 +242,18 @@ class ShopifyBookService:
                 type=MetafieldType.single_line_text_field,
             )
         )
+        self._create_metafield_definition(
+            CreateMetafieldDefinitionInput(
+                name="ISBN",
+                key="isbn",
+                type=MetafieldType.single_line_text_field,
+            )
+        )
         self._create_metafield_definition(
             CreateMetafieldDefinitionInput(
                 name="Staff Comment",
                 key="staff_comment",
-                type=MetafieldType.multi_line_text_field,
+                type=MetafieldType.single_line_text_field,
             )
         )
         self._create_metafield_definition(
@@ -207,7 +264,7 @@ class ShopifyBookService:
             )
         )
 
-    def _get_metafield_definitions(self) -> List[MetafieldDefinition]:
+    def _get_metafield_definitions(self) -> t.List[MetafieldDefinition]:
         """
         Gets all metafield definitions in the Shopify store.
 
